<!-- $Revision: 6820 $ -->
<html>
<head>
    <link rel="SHORTCUT ICON" href="<mm-favicon>">
    <title>Pers&ouml;nliche Einstellungen f&uuml;r <MM-Presentable-User> und die Liste <MM-List-Name>
    </title>
</head>
<BODY BGCOLOR="#ffffff">
    <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#99CCFF"><B>
        <FONT COLOR="#000000" SIZE=+1>
        Pers&ouml;nliche Einstellungen von <MM-Presentable-User> f&uuml;r die Liste <MM-List-Name>
	</FONT></B></TD></TR>
    </TABLE>
<p>
<table width="100%" border="0" cellspacing="5" cellpadding="5">
    <tr><td>
        <b>Abonnement-Status von <MM-Presentable-User></b>, Passwort und
        pers&ouml;nliche Einstellungen f&uuml;r die Liste <MM-List-Name>.
        </td><td><MM-Form-Start><mm-logout-button><MM-Form-End></td>
    </tr><tr>
        <td colspan="2">
        <MM-Case-Preserved-User>

        <MM-Disabled-Notice>

        <p><mm-results>
        </td>
    </tr>
</table>

<MM-Form-Start>
<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#FFF0D0" colspan="2">
        <FONT COLOR="#000000">
        <B>&Auml;nderung der Abonnementsinformation f&uuml;r die Liste <MM-List-Name></B>
	</FONT></TD></TR>
    <tr><td colspan="2">Sie k&ouml;nnen die Adresse unter der Sie die Liste
        beziehen &auml;ndern, indem Sie die neue Adresse in die Felder unten
        eintragen. <B>Hinweis:</B> An die neue Adresse wird eine
        Best&auml;tigungs-Email geschickt und die &Auml;nderung mu&szlig; best&auml;tigt werden,
        bevor sie aktiv wird.
        <p>Best&auml;tigungs-Emails verfallen nach ca. <mm-pending-days>.

        <p>Ebenso k&ouml;nnen Sie Ihren "Realname" setzen oder &auml;ndern (z.B. <em>Paul Schmidt</em>).

        <p>Wenn Sie die &Auml;nderungen f&uuml;r alle Ihre Abonnements auf <mm-host>
        vornehmen m&ouml;chen, aktivieren Sie die Option <em>Global &auml;ndern</em>!

        </td></tr>
    <tr><td><center>
        <table border="0" cellspacing="2" cellpadding="2" width="80%" cols="2">
        <tr><td bgcolor="#dddddd"><div align="right">Neue Adresse:</div></td>
            <td><mm-new-address-box></td>
            </tr>
        <tr><td bgcolor="#dddddd"><div align="right">Zur Best&auml;tigung nochmal:</div></td> 
            <td><mm-confirm-address-box></td>
            </tr>
        </tr></table></center>
        </td>
        <td><center>
        <table border="0" cellspacing="2" cellpadding="2" width="80%" cols="2">
            <tr><td bgcolor="#dddddd"><div align="right">Ihr Name (optional):</div></td>
            <td><mm-fullname-box></td>
            </tr>
        </table></center>
        </td>
        </tr>
    <tr><td colspan="2"><center><mm-change-address-button>
        <p><mm-global-change-of-address>Global &auml;ndern</center></td>
    </tr>
</table>

<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="5" CELLPADDING="5">
    <TR><TD WIDTH="50%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>Abbestellen von <MM-List-Name></B></td>

	<TD WIDTH="50%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>Ihre anderen Abonnements bei <MM-Host></B>
	</FONT></TD></TR>

    <tr><td>
        Aktivieren Sie die Best&auml;tigungs-Checkbox und dr&uuml;cken Sie diesen
        Knopf um Ihr Abonnement dieser Mailingliste zu beenden.
        <strong>Warnung:</strong> 
        Diese Aktion wird sofort aktiv!
        <p>
        <center><MM-Unsubscribe-Button></center></td>
    <td>
        Sie k&ouml;nnen sich eine Liste aller Ihrer Abonnements auf <mm-host>
        anzeigen lassen. Benutzen Sie dies, falls Sie dieselben &Auml;nderungen
        auch f&uuml;r die anderen Listen gelten lassen wollen.

        <p>
        <center><MM-Other-Subscriptions-Submit></center>
	</TD></TR>
</table>

<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD COLSPAN=2 WIDTH="100%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>Ihr Passwort f&uuml;r die Liste <MM-List-Name></B>
	</FONT></TD></TR>

    <tr valign="TOP"><td WIDTH="50%">
        <a name=reminder>
        <center>
        <h3>Haben Sie Ihr Passwort vergessen?</h3>
        </center>
        Klicken Sie auf diesen Knopf und Ihnen wird das Passwort an Ihre
        Adresse zugeschickt.
        <p><MM-Umbrella-Notice>
        <center>
        <MM-Email-My-Pw>
        </center>
        </td>

    <td WIDTH="50%">
        <a name=changepw>
        <center>
        <h3>&Auml;nderung des Passworts</h3>
        <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2" WIDTH="70%" COLS=2>
            <TR><TD BGCOLOR="#dddddd"><div align="right">Neues
                Passwort:</div></TD>
                <TD><MM-New-Pass-Box></TD>
                </TR>
            <TR>
                <TD BGCOLOR="#dddddd"><div align="right">Nochmal zur Best&auml;tigung:</div></TD>
                <TD><MM-Confirm-Pass-Box></TD>
            </TR>
        </table>

        <MM-Change-Pass-Button>
        <p><center><mm-global-pw-changes-button>Global &auml;ndern
        </center>
</TABLE>

<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>Ihre pers&ouml;nlichen Einstellungen f&uuml;r <MM-List-Name></B>
	</FONT></TD></TR>
</table>

<p>
<i><strong>Die aktuellen Werte sind mit H&auml;kchen versehen.</strong></i>

<p>Bitte beachten Sie, da&szlig; einige der Optionen eine <em>Global &auml;ndern</em>
Checkbox besitzen. Deren ankreuzen bewirkt, da&szlig; die &Auml;nderungen f&uuml;r
jede von Ihnen abonnierte Mailingliste auf <mm-host> vorgenommen werden.
Klicken Sie auf <em>List my other subscriptions</em> um zu sehen, welche
weitern Abonnement Sie haben.
<p>
<TABLE BORDER="0" CELLSPACING="3" CELLPADDING="4" WIDTH="100%">
    <tr><TD BGCOLOR="#cccccc">
        <a name="disable">
        <strong>Mailzustellung</strong></a><p>
        Setzen Sie diese Option auf <em>An</em> um Nachrichten von der
        Liste zu empfangen.
        Setzen Sie diese Option auf <em>Aus</em> um keine Nachrichten
        von der Liste zu empfangen (z.B. weil Sie im Urlaub sind)
	Wenn Sie die Mailzustellung ausstellen, vergessen Sie nicht, diese
        nach Ihrem Urlaub wieder anzustellen!
        </td><td bgcolor="#cccccc">
        <mm-delivery-enable-button>An<br>
        <mm-delivery-disable-button>Aus<p>
        <mm-global-deliver-button><i>Global &auml;ndern</i>
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>Zusammenfassungs Modus</strong><p>
        Wenn Sie den Zusammenfassungs Modus aktivieren, erhalten Sie die
        Nachrichten eines Tages geb&uuml;ndelt anstatt einzeln.
        Wenn der Zusammenfassungs Modus von an auf aus gewechselt wird,
        erhalten Sie eine letzet Zusammenfassung!
        </td><td bgcolor="#cccccc">
        <MM-Undigest-Radio-Button>Aus<br>
        <MM-Digest-Radio-Button>An
        </td></tr>
        
    <tr><TD BGCOLOR="#cccccc">
        <strong>MIME oder Plain Text Zusammenfassungen?</strong><p>
        Ihr Mailprogramm unterst&uuml;tzt MIME Zusammenfassungen (oder nicht!).
        Generell sind MIME Zusammenfassungen bevorzugt, aber falls Sie ein
        Problem damit haben, diese zu lesen, w&auml;hlen Sie hier doch einfach
        Plain Text Zusammenfassungen.
        </td><td bgcolor="#cccccc">
        <MM-Mime-Digests-Button>MIME<br>
        <MM-Plain-Digests-Button>Plain Text<p>
        <mm-global-mime-button><i>Global &auml;ndern</i>
        </td></tr>
        
    <tr><TD BGCOLOR="#cccccc">
        <strong>Wollen Sie Ihre eigenen Nachrichten &uuml;ber die Liste zur&uuml;ckerhalten?</strong><p>
        Normalerweise erhalten Sie JEDE Mail. Wenn Sie Ihre eigenen Mails
        nicht nochmal sehen m&ouml;chten, setzen Sie diese Option auf <em>Nein</em>.
        </td><td bgcolor="#cccccc">
        <mm-dont-receive-own-mail-button>Nein<br>
        <mm-receive-own-mail-button>Ja
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>Best&auml;tigunsmail wenn Sie E-Mail an die Liste schicken?</strong><p>
        </td><td bgcolor="#cccccc">
        <mm-dont-ack-posts-button>Nein<br>
        <mm-ack-posts-button>Ja
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Monatliche Erinnerungsmail mit Passwort?</strong><p>
        Einmal im Monat erhalten Sie eine Erinnerungsmail mit Ihrem Passwort
        f&uuml;r jede Liste, die Sie abonniert haben.
        Sie k&ouml;nnen dies auf Listenbasis an- und abstellen, indem Sie hier 
        <em>Nein</em> w&auml;hlen. Wenn Sie die Erinnerungsmail f&uuml;r alle Ihre
        Abonnements abstellen, erhalten Sie keinerlei Erinnerungsmails mehr.
        </td><td bgcolor="#cccccc">
        <mm-dont-get-password-reminder-button>Nein<br>
        <mm-get-password-reminder-button>Ja<p>
        <mm-global-remind-button><i>Global &auml;ndern</i>
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>In der Liste der Abonnenten unsichtbar machen?</strong><p>
        Wenn sich jemand die Mitglieder der Liste anzeigen l&auml;&szlig;t, wird Ihre
        E-Mail-Adresse normalerweise angezeigt (in einer leicht modifizierten
        Art und Weise um es Adresssammlern nicht zu leicht zu machen).
        Wenn Sie w&uuml;nschen, da&szlig; Ihre Adresse nicht gezeigt wird, w&auml;hlen Sie
        hier bitte <em>Ja</em>.
        </td><td bgcolor="#cccccc">
        <MM-Public-Subscription-Button>Nein<br>
        <MM-Hide-Subscription-Button>Ja
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>Welche Sprache bevorzugen Sie?</strong><p>
        </td><td bgcolor="#cccccc">
        <MM-list-langs>
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Welche Themen interessieren Sie?</strong><p>
                Sofern hier rechts Themen aufgelistet sind, k&ouml;nnen Sie ein 
                oder mehrere Themen ausw&auml;hlen und damit den 
                Listenverkehr auf der Mailingliste filtern, so da&szlig; Sie nur
                einen Teil der Nachrichten empfangen.
                Wenn eine Nachricht auf ein Thema "pa&szlig;t", dann erhalten Sie
                die Nachricht, ansonsten nicht.

                <p>Wenn eine Nachricht auf kein Thema pa&szlig;t, h&auml;ngt es
                von der folgenden Option ab, ob Sie keine oder alle
                Nachrichten erhalten. 
        </td><td bgcolor="#cccccc">
        <mm-topics>
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>M&ouml;chten Sie Nachrichten erhalten, auf die kein Themen-Filter
        "pa&szlig;t"?</strong><p>

                Diese Option hat nur Auswirkungen wenn Sie oben mindestens
                ein Thema angegeben haben. Sie gibt an wie die
                Standardzustellungsregel f&uuml;r Nachrichten lautet, auf die
                kein Thema pa&szlig;t.
                Geben Sie hier <em>Nein</em> an, bedeutet dies, da&szlig; Sie
                keine Nachrichten erhalten, wenn kein Thema pa&szlig;t,
                wohingegen <em>Ja</em> bedeutet, da&szlig; Sie diese Nachrichten
                doch erhalten!

                <p>Wenn Sie gar keine Themen angegeben haben, erhalten Sie
                selbstverst&auml;ndliche alle Nachrichten an die Mailingliste!
        </td><td bgcolor="#cccccc">
        <mm-suppress-nonmatching-topics>Nein<br>
        <mm-receive-nonmatching-topics>Ja
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Mehrfache Kopien von Nachrichten vermeiden?</strong><p>

                Wenn Sie explizit im Feld <tt>To:</tt> oder <tt>Cc:</tt>
		im Kopf einer E-Mail aufgef&uuml;hrt sind, k&ouml;nnen Sie
		sich daf&uuml;r entscheiden, keine Kopie dieser
		Nachricht &uuml;ber die Mailingliste zu erhalten.
                W&auml;hlen Sie <em>Ja</em>, um mehrfache Kopien zu
		vermeiden; w&auml;hlen Sie <em>Nein</em>, um diese
		Kopien weiterhin zu erhalten.

		<p>Wenn f&uuml;r die Mailingliste
		mitgliederpersonalisierte Nachrichten eingeschaltet
		sind und Sie sich daf&uuml;r entschieden haben, Kopien
		zu erhalten, wird jeder von diesen ein Feld
		<tt>X-Mailman-Copy: yes</tt> im Kopf hinzugef&uuml;gt.

        </td><td bgcolor="#cccccc">
        <mm-receive-duplicates-button>Nein<br>
        <mm-dont-receive-duplicates-button>Ja<p>
        <mm-global-nodupes-button><i>Global &auml;ndern</i>
        </td></tr>

    <tr><TD colspan="2">
        <center><MM-options-Submit-button></center>
        </td></tr>

</table>
</center>
<p>
<MM-Form-End>

<MM-Mailman-Footer>
</body>
</html>
