<!-- $Revision: 3817 $ -->
<HTML>
  <HEAD>
    <TITLE><MM-List-Name> Medlemmer</TITLE>
  
  </HEAD>
  <BODY BGCOLOR="#ffffff">

    <P>
    <TABLE WIDTH="100%" COLS="1" BORDER="0" CELLSPACING="4" CELLPADDING="5">
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	  <B><FONT COLOR="#000000" SIZE="+1"><MM-List-Name>
		Medlemmer</FONT></B>
	</TD>
      </TR>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" ALIGN="CENTER">
	    
          <P align = "right"> <MM-lang-form-start><MM-displang-box>
                       <MM-list-langs><MM-form-end></p>        

	  <P>Klikk p&aring; adressen din for &aring; g&aring; til din personlige side.
<br><I>(Adresser i parentes har stoppet mottak av meldinger til listen.)</I></P>
	</TD>
      </TR>
      <TR WIDTH="100%" VALIGN="top">
	<TD BGCOLOR="#FFF0D0" WIDTH="50%">
	  <center>
	    <B><FONT COLOR="#000000"><MM-Num-Reg-Users>
		  Medlemmer i normal-modus p&aring; <MM-List-Name>:</FONT></B>
	  </center>
	</TD>
	<TD BGCOLOR="#FFF0D0" WIDTH="50%">
	  <center>
	    <B><FONT COLOR="#000000"><MM-Num-Digesters> Medlemmer i sammendrag-modus p&aring;
		  <MM-List-Name>:</FONT></B> 
	  </center>
	</TD>
      </TR>
      <TR VALIGN="top">
	<td>
	  <P><MM-Regular-Users>
	</td>
	<td>
	  <P><MM-Digest-Users>
	</td>
      </tr>
    </table>
<MM-Mailman-Footer>
</BODY>
</HTML>
