Esta p&aacute;xina cont&eacute;n un subconxunto dos envíos &aacute; 
rolda de distribución <em>%(listname)s</em> que requiren 
da s&uacute;a conformidade. Actualmente amosa %(description)s

<p> Para cada solicitude administrativa, seleccione a acción que se debe tomar
ao premer <b>mandar todos os datos</b> despois de rematar.
Pode
achar máis información <a href="%(detailsurl)s">aquí</a>.

<p>Tamén pode <a href="%(summaryurl)s">ver un resumo</a> de todas as solicitudes
pendentes.
