Prehľad požiadaviek pre konferenciu <a href=\"%(adminurl)s\"><em>%(listname)s</em></a>.

Táto stránka obsahuje prehľad vštkých požiadaviek pre administrátora
zoradený tak, že požiadavky od jedného účastníka sú zlúčené dokopy
a môže o nich byť rozhodnuté naraz.

Žiadosti o prihlásenie a odhlásenie sú radené ako prvé a za nimi
prípadné príspevky, ktoré čakajú na schválenie moderátorom.

<p>Pri každej administratívnej požiadavke musíte vybrať činnosť, ktorá sa
s ňou má previesť a nakoniec vybrané činnosti uskutočníte kliknutím na 
<b>Potvrdiť všetky zmeny</b>. Podrobnejšie informáce o tom, ako
zaobchádzať s administratívnym rozhraním nájdete 
<a href="%(detailsurl)s">pod týmto odkazom</a>.

<p>Tiež si môžete prezrieť detailný prehľad všetkých
<a href="%(viewallurl)s">čakajúcich požiadaviek</a> kde je každý
príspovek zobrazovaný samostatne.
