<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<HTML>
  <HEAD>
     <title>Gli archivi della lista %(listname)s</title>
     <META NAME="robots" CONTENT="noindex,follow">
  </HEAD>
  <BODY BGCOLOR="#ffffff">
     <h1>Gli archivi della lista %(listname)s</h1>
     <p>
      Non sono stati ancora inviati messaggi a questa lista e gli
      archivi sono ancora vuoti. 
      Puoi avere <a href="%(listinfo)s">altre informazioni
      su questa lista</a>.
     </p>
  </BODY>
  </HTML>
