<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<HTML>
  <HEAD>
       <title>Arquivo da rolda %(listname)s</title>
     <META NAME="robots" CONTENT="noindex,follow">
  </HEAD>
  <BODY BGCOLOR="#ffffff">
     <h1>Arquivo da rolda %(listname)s</h1>
     <p>
      Aínda non se enviou ningunha mensaxe a esta rolda de xeito que
      o arquivo está baleiro.  Pode obter, na ligazón seguinte, <a href="%(listinfo)s">
      máis información sobre esta rolda</a>.
     </p>
  </BODY>
  </HTML>
